@@ -7,7 +7,7 @@ use Moo;
 use Hash::Flatten ();
 use Hash::Merge   ();
 
-our $VERSION = '0.000003'; # VERSION
+our $VERSION = '0.000004'; # VERSION
 
 
 sub BUILDARGS {
@@ -19,7 +19,9 @@ sub BUILDARGS {
 
 sub BUILD {
     my ($self) = @_;
+    my $dom = lc $self->domain;
 
+    $self->{snapshot} = { map {$_ => $ENV{$_}} grep { /^$dom\_/i } keys %ENV };
     return $self->load({%ENV}) if $self->autoload;
 }
 
@@ -37,9 +39,23 @@ has domain => (
 );
 
 
-has override => (
+has lifecycle => (
     is       => 'ro',
     required => 0,
+    default  => 0
+);
+
+
+has mirror => (
+    is       => 'rw',
+    required => 0,
+    default  => 1
+);
+
+
+has override => (
+    is       => 'rw',
+    required => 0,
     default  => 1
 );
 
@@ -77,9 +93,10 @@ sub load {
             $map => Hash::Flatten->new->unflatten($hash)
         );
 
-        # re-setting ... re-formatting
-        while (my($key, $val) = each(%{$hash})) {
-            $ENV{$self->to_env_key($key)} = $val;
+        if ($self->mirror) {
+            while (my($key, $val) = each(%{$hash})) {
+                $ENV{$self->to_env_key($key)} = $val;
+            }
         }
     }
 
@@ -154,9 +171,11 @@ sub subdomain {
     my ($self, $key) = @_;
     my $dom  = $self->domain;
     my $copy = ref($self)->new(
-        autoload => 0,
-        override => $self->override,
-        domain   => $dom
+        autoload  => 0,
+        override  => $self->override,
+        lifecycle => $self->lifecycle,
+        mirror    => $self->mirror,
+        domain    => $dom
     );
 
     ($copy->{subdomain} = $self->to_dom_key($key)) =~ s/^$dom(\.)?//;
@@ -165,15 +184,6 @@ sub subdomain {
     return $copy;
 }
 
-sub to_env_key {
-    my ($self, $key) = @_;
-    my $dom = $self->domain;
-
-    $key =~ s/^$dom//;
-
-    return uc join '_', $dom, split /\./, $key
-}
-
 sub to_dom_key {
     my ($self, $key) = @_;
     my $dom = $self->domain;
@@ -186,6 +196,27 @@ sub to_dom_key {
     return lc join '.', @prefix, split /_/, $key;
 }
 
+sub to_env_key {
+    my ($self, $key) = @_;
+    my $dom = $self->domain;
+
+    $key =~ s/^$dom//;
+
+    return uc join '_', $dom, split /\./, $key
+}
+
+sub DESTROY {
+    my ($self) = @_;
+
+    if ($self->lifecycle) {
+        my $environment = $self->environment;
+        my $snapshot    = $self->{snapshot};
+
+        delete $ENV{$_} for grep { ! exists $snapshot->{$_} } keys %{$environment};
+        $ENV{$_} = $snapshot->{$_} for keys %{$snapshot};
+    }
+}
+
 1;
 
 __END__
@@ -198,7 +229,7 @@ Config::Environment - Application Configuration via Environment Variables
 
 =head1 VERSION
 
-version 0.000003
+version 0.000004
 
 =head1 SYNOPSIS
 
@@ -258,6 +289,18 @@ set to true by default.
 The domain attribute contains the environment variable prefix used as context
 to differentiate between other environment variables.
 
+=head2 lifecycle
+
+The lifecycle attribute contains a boolean value which if true restricts any
+environment variables changes to life of the class instance. This attribute
+is set to false by default.
+
+=head2 mirror
+
+The mirror attribute contains a boolean value which if true copies any
+configuration assignments to the corresponding environment variables. This
+attribute is set to true by default.
+
 =head2 override
 
 The override attribute contains a boolean value which determines whether
@@ -308,8 +351,8 @@ specific to the instantiated object's domain and instance.
 
 =head2 subdomain
 
-The subdomain method returns a copy of the existing class instance modifying the
-domain for easier access to long/deep keys.
+The subdomain method returns a copy of the class instance with a modified domain
+reference for easier access to nested configuration keys.
 
     my $db  = $self->subdomain('db');
     my $db1 = $db->subdomain('1');
